from excelsior import Scanner, AlignSpec, HorizAlignment
import os

base_dir = os.path.dirname(os.path.abspath(__file__))
inp_filename = os.path.join(base_dir, "../../test/style_test.xlsx")

out_filename = os.path.join(base_dir, "../../test/style_test_out_py.xlsx")

scanner = Scanner(inp_filename)
editor = scanner.open_editor(scanner.get_sheets()[0])
# .set_fill("B24:B28", "FFFF00")\
editor\
        .set_font("D4:D8", "Arial", 12.0, True, False)\
        .set_border("A1:C3", "thin")\
        .set_font("A1:C3", "Calibri", 10.0, False, True, AlignSpec(horiz=HorizAlignment.Center))\
        .merge_cells("B12:D12")
editor.save(out_filename)
print("Done")



from excelsior import Scanner
import os
base_dir = os.path.dirname(os.path.abspath(__file__))
file_path = os.path.join(base_dir, "../../test/test_new_ws.xlsx")
scanner = Scanner(file_path)
print(scanner.get_sheets())
editor = scanner.open_editor(scanner.get_sheets()[0])
editor.add_worksheet('Sheet2')
editor.add_worksheet('Sheet3').append_table_at([["10", "20", "30"], ["30", "40", "50"]], "B2")
editor.add_worksheet_at('Title', 0).append_table_at([["1", "2", "3"], ["3", "4", "5"]], "A1")
editor.with_worksheet("Sheet2").append_table_at([["1", "2", "3"], ["3", "4", "5"]], "A1")
editor.save(file_path + "_out.xlsx")
assert 'Sheet2' in Scanner(file_path + "_out.xlsx").get_sheets() 
assert 'Sheet3' in Scanner(file_path + "_out.xlsx").get_sheets() 
assert Scanner(file_path + "_out.xlsx").get_sheets()[0] == "Title"

print('Done')


"""
excelsior: тонкая обёртка над нативным расширением, собранным через maturin.

Файл нужен только для editable-установок (`maturin develop`): без него каталог
`excelsior/` считается namespace-package и Python не подхватывает лежащий
внутри бинарный модуль `excelsior*.pyd`.
"""

from importlib import import_module as _import_module
import sys as _sys

# Импортируем бинарник как подпакет:  excelsior.excelsior
try:
    _ext = _import_module("." + __name__.split(".")[-1], package=__name__)
except ModuleNotFoundError as exc:          # pragma: no cover
    raise ImportError(
        "Не удалось загрузить нативное расширение для 'excelsior'. "
        "Убедитесь, что вы запускали `maturin develop` или установили wheel."
    ) from exc

# Экспортируем все публичные имена
globals().update(
    {k: v for k, v in _ext.__dict__.items() if not k.startswith("_")}
)

# Чтобы `importlib.reload(excelsior)` работал предсказуемо
_sys.modules[__name__] = _ext

# Чистим внутренние ссылки
del _import_module, _sys, _ext



from excelsior import Scanner
import polars as pl
import os
df = pl.DataFrame(
    {
        "int": [1, 2, 3],
        "float": [1.1, 2.2, 3.3],
        "string": ["a", "b", "c"],
        "bool": [True, False, True], # not yet fully supported, only as string
        "long_string" : ["123" * 10, "123" * 10, "123" * 10]
    }
)
print(df)
base_dir = os.path.dirname(os.path.abspath(__file__))
inp_filename = os.path.join(base_dir, "../../test/test_polars.xlsx")
out_filename = os.path.join(base_dir, "../../test/test_polars_appended.xlsx")

scanner = Scanner(inp_filename)
editor = scanner.open_editor(scanner.get_sheets()[0])
# editor.with_polars(df, "A1")
editor.add_worksheet('polars_ws').with_polars(df, "B4")
editor.add_worksheet('polars_ws_2').with_polars(df)
editor.save(out_filename)


from excelsior import Scanner
import os

base_dir = os.path.dirname(os.path.abspath(__file__))
file_path = os.path.join(base_dir, "../../test/style_test.xlsx")
file_path_out = os.path.join(base_dir, "../../test/style_test_borders_py.xlsx")
scanner = Scanner(file_path)
print(scanner.get_sheets())
editor = scanner.open_editor(scanner.get_sheets()[0])
editor.set_border("D4:G8", "thin").merge_cells('D4:G4').set_font('D4:G4', 'Arial', 12, False, False)
editor.save(file_path_out)



from excelsior import AlignSpec, HorizAlignment, Scanner
import os
base_dir = os.path.dirname(os.path.abspath(__file__))
scanner = Scanner(os.path.join(base_dir, "../tests/100mb.xlsx"))
editor = scanner.open_editor("Tablo3")
def generate_table(width: int, height: int):
    table = [[str(i) for i in range(width)] for _i in range(height)]
    return table
data = generate_table(5, 2000)
last_col = max(editor.last_rows_index("A:E")) + 1
for row in data:
    editor.append_row(row)
editor.set_font(f'A{last_col}:E{last_col + 2000}', "Arial", size=14, align=AlignSpec(HorizAlignment.Center))  
editor.set_border(f'A{last_col}:E{last_col + 2000}', 'thick')  
editor.save(os.path.join(base_dir, "100mb_excelsior_style.xlsx"))
